join_datasets <- function(data, multimodel, n_members) {
  
  ## Taking the first model as "template"
  ##TODO: the s2dv_cube has only the first model's info
  output <- data[[1]]
  
  if (is.null(output$fcst$data)) {
    exps <- 'hcst'
  } else {exps <- c('hcst','fcst')}
  
  for (exp in exps) {
    
    ## New dimensions of the arrays
    if (isFALSE(multimodel)) { ## Individual models
      n_models <- length(data)
      max_members <- max(n_members[[exp]])
    } else if (isTRUE(multimodel)) { ## Multimodel
      n_models <- length(data)
      max_members <- sum(n_members[[exp]])
    } else if (identical(multimodel,'both')) { ## Individual models and multimodel
      n_models <- length(data) + 1
      max_members <- sum(n_members[[exp]])
    } else {
      stop('Incorrect "Multimodel" in the recipe. It must be "yes", "no" or "both".')
    }
    dims <- dim(data[[1]][[exp]]$data)
    dims['dat'] <- n_models
    dims['ensemble'] <- max_members
    stopifnot(identical(names(dims), c('dat', 'var', 'sday', 'sweek', 'syear', 'time', 'latitude', 'longitude', 'ensemble')))
    
    ## Creating empty models and multimodel
    output[[exp]]$data <- array(data = NA, dim = dims)
    ## Filling the models
    for (model in 1:length(data)) {
      output[[exp]]$data[model, , , , , , , , 1:n_members[[exp]][model]] <- data[[model]][[exp]]$data
    }
    
    ## Filling the multimodel
    if (isTRUE(multimodel)) { ## Multimodel
      output[[exp]]$data <- CSTools::MergeDims(data = output[[exp]]$data, 
                                               merge_dims = c('ensemble', 'dat'),
                                               rename_dim = 'ensemble', 
                                               na.rm = TRUE)
      output[[exp]]$data <- s2dv::InsertDim(data = output[[exp]]$data,
                                            posdim = 1,
                                            lendim = 1,
                                            name = 'dat')
    } else if (identical(multimodel,'both')) { ## Individual models and multimodel
      output[[exp]]$data[n_models, , , , , , , , 1:max_members] <- 
        CSTools::MergeDims(data = output[[exp]]$data, 
                           merge_dims = c('ensemble', 'dat'),
                           rename_dim = 'ensemble', 
                           na.rm = TRUE)
    }
  }
  
  return(output)
}
